@@ -12,7 +12,6 @@ from loguru import logger
 from pydantic import parse_obj_as
 
 from gable.openapi import (
-    CheckComplianceDataAssetsPySparkRequest,
     CheckComplianceDataAssetsS3Request,
     CheckDataAssetCommentMarkdownResponse,
     CheckDataAssetDetailedResponse,
@@ -29,6 +28,8 @@ from gable.openapi import (
     DeleteDataAssetsResponse,
     ErrorResponse,
     ErrorResponseDeprecated,
+    GetConfigRequest,
+    GetConfigResponse,
     GetNpmCredentialsResponse,
     GetPipCredentialsResponse,
     GetScaRunStatusResponse,
@@ -37,11 +38,11 @@ from gable.openapi import (
     PostContractResponse,
     PostScaStartRunRequest,
     PostScaStartRunResponse,
-    RegisterDataAssetPySparkRequest,
     RegisterDataAssetS3Request,
     RegisterDataAssetsRequest,
     RegisterDataAssetsResponse,
     ResponseType,
+    ScaResultsUploadRequest,
 )
 
 T = TypeVar("T")
@@ -248,6 +249,29 @@ class GableAPIClient:
             )
         return response
 
+    def get_config(
+        self, get_config_request: GetConfigRequest
+    ) -> GetConfigResponse | None:
+        """
+        Get the backend config
+        """
+        try:
+            response, success, status_code = self._get(
+                "v0/config",
+                json=get_config_request.json(by_alias=True, exclude_none=True),
+            )
+            response = GetConfigResponse.parse_obj(response)
+        except Exception as e:
+            logger.opt(exception=e).debug("Error getting config")
+            raise Exception(
+                f"Error getting config: {e}. Re-run with --debug for more information."
+            )
+        if status_code == 404:
+            return None
+        if not success:
+            raise Exception(f"Failed to get config: ({status_code}) {response}")
+        return response
+
     def post_data_assets_check_compliance(
         self, request: DataAssetsCheckComplianceRequest
     ) -> Union[
@@ -279,23 +303,6 @@ class GableAPIClient:
         else:
             return ErrorResponse.parse_obj(result)
 
-    def post_data_asset_register_pyspark(
-        self, request: RegisterDataAssetPySparkRequest
-    ) -> tuple[Union[IngestDataAssetResponse, ErrorResponseDeprecated], bool, int]:
-        response, success, status_code = self._post(
-            "v0/data-asset/register/pyspark",
-            json=request.dict(by_alias=True),
-        )
-        if isinstance(response, dict) and "registered" in response:
-            result = IngestDataAssetResponse.parse_obj(response)
-        else:
-            result = ErrorResponseDeprecated.parse_obj(response)
-        return (
-            result,
-            success,
-            status_code,
-        )
-
     def post_data_asset_register_s3(
         self, request: RegisterDataAssetS3Request
     ) -> tuple[Union[IngestDataAssetResponse, ErrorResponseDeprecated], bool, int]:
@@ -313,21 +320,6 @@ class GableAPIClient:
             status_code,
         )
 
-    def post_check_compliance_data_assets_pyspark(
-        self, request: CheckComplianceDataAssetsPySparkRequest
-    ) -> Union[
-        ErrorResponse,
-        CheckDataAssetCommentMarkdownResponse,
-        list[CheckDataAssetResponse],
-    ]:
-        response, _success, _status_code = self._post(
-            "v0/data-assets/check-compliance/pyspark",
-            data=request.json(by_alias=True, exclude_none=True),
-        )
-        return parse_data_assets_check_compliance_response(
-            request.responseType, response
-        )
-
     def post_check_compliance_data_assets_s3(
         self, request: CheckComplianceDataAssetsS3Request
     ) -> Union[
@@ -379,6 +371,20 @@ class GableAPIClient:
         else:
             return ErrorResponse.parse_obj(response), success, status_code
 
+    def post_sca_results(
+        self,
+        request: ScaResultsUploadRequest,
+    ) -> tuple[Union[dict, ErrorResponse], bool, int]:
+        """Post SCA results to the API endpoint. Can be called multiple times with chunks."""
+        response, success, status_code = self._post(
+            "v0/sca/results",
+            json=json.loads(request.json(by_alias=True, exclude_none=True)),
+        )
+        if success:
+            return response, success, status_code
+        else:
+            return ErrorResponse.parse_obj(response), success, status_code
+
     def get_data_asset(
         self, data_asset_resource_name: str
     ) -> Union[DataAsset, ErrorResponse]:
@@ -411,12 +417,12 @@ class GableAPIClient:
         else:
             return ErrorResponse.parse_obj(response)
 
-    def get_pyping(self):
-        return self._get("v0/pyping")
-
     def get_ping(self):
         return self._get("v0/ping")
 
+    def get_version(self):
+        return self._get("v0/_version")
+
     def get_contract(self, contract_id) -> ContractOutput:
         response, success, status_code = self._get("v0/contract/" + contract_id)
         if not success or not isinstance(response, ContractOutput):
