@@ -1,11 +1,14 @@
 import shutil
+import sys
 
 import click
+from loguru import logger
 
 from gable.cli.helpers.jsonpickle import register_jsonpickle_handlers
 from gable.cli.helpers.logging import configure_default_click_logging
 from gable.cli.options import global_options
 from gable.cli.version import print_version
+from gable.openapi import CreateTelemetryRequest, TelemetryType
 
 from .commands.auth import auth
 from .commands.contract import contract
@@ -50,5 +53,27 @@ cli.add_command(ping)
 cli.add_command(ui)
 
 
+@cli.result_callback()
+@click.pass_context
+def process_result(ctx, result, **kwargs):
+    """This function runs after the command has finished."""
+    try:
+        argv_cleaned = sys.argv[1:]
+        for forbidden_arg in ["--api-key", "--proxy-password"]:
+            if forbidden_arg in argv_cleaned:
+                key_index = argv_cleaned.index(forbidden_arg)
+                argv_cleaned = argv_cleaned[1:key_index] + argv_cleaned[key_index + 2 :]
+
+        ctx.obj.client.post_telemetry(
+            CreateTelemetryRequest(
+                id=None,
+                data={"argv": argv_cleaned},
+                type=TelemetryType.GABLE_CLIENT,
+            )
+        )
+    except Exception as e:
+        logger.debug(f"Error posting telemetry: {e}")
+
+
 if __name__ == "__main__":
     cli()
