@@ -16,8 +16,13 @@ from gable.cli.commands.asset_plugins.baseclass import (
     AssetPluginAbstract,
     ExtractedAsset,
 )
-from gable.cli.helpers.data_asset import get_git_repo, get_relative_project_path
+from gable.cli.helpers.data_asset import (
+    get_git_repo,
+    get_relative_project_path,
+    merge_rules_file_with_backend_config,
+)
 from gable.cli.helpers.emoji import EMOJI
+from gable.cli.helpers.exclude_options import resolve_excludes_from_flag_and_rules
 from gable.cli.helpers.npm import (
     get_sca_prime_results,
     prepare_npm_environment,
@@ -126,6 +131,13 @@ class ScaPrimePlugin(AssetPluginAbstract):
             )
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
+                exclude = kwargs.get("exclude")
+                rules_file = kwargs.get("rules_file")
+                if exclude and rules_file:
+                    kwargs["exclude"] = resolve_excludes_from_flag_and_rules(
+                        exclude,
+                        rules_file,
+                    )
                 return func(*args, **kwargs)
 
             return wrapper
@@ -174,6 +186,11 @@ class ScaPrimePlugin(AssetPluginAbstract):
                 annotations = list(typed_config.get("annotation", []))
                 exclude_patterns = config.get("exclude_pattern", [])
 
+                # Here, read the rules file, get the backend rules config, merge them, save to a new temp file, and then call sca prime with it
+                updated_rules_file = merge_rules_file_with_backend_config(
+                    rules_file, client, self.language, project_root
+                )
+
                 prepare_npm_environment(client)
                 run_sca_npx_help(client.endpoint)
                 semgrep_bin_path = self.install_semgrep()
@@ -186,7 +203,7 @@ class ScaPrimePlugin(AssetPluginAbstract):
                     lang=self.source_type(),
                     sca_debug=("debug" in config),
                     semgrep_bin_path=semgrep_bin_path,
-                    rules_file=rules_file,
+                    rules_file=updated_rules_file,
                 )
                 findings = get_sca_prime_results(
                     sca_prime_future, client, project_root, post_metrics=False
