@@ -3,6 +3,8 @@ from typing import Generator, List, Optional
 
 import click
 from click.core import Context as ClickContext
+from loguru import logger
+
 from gable.api.client import GableAPIClient
 from gable.cli.helpers.contract import (
     contract_files_to_contract_inputs,
@@ -19,7 +21,6 @@ from gable.openapi import (
     PostContractResponse,
 )
 from gable.sdk.models import ContractPublishResponse
-from loguru import logger
 
 CONTRACT_VALIDATE_CHUNK_SIZE = 20
 
@@ -140,7 +141,8 @@ def _validate_contract_chunk(
     epilog="""Examples:\n
 \b
   gable contract bulk-update-enforcement-levels BLOCK
-  gable contract bulk-update-enforcement-levels ALERT data-asset-id-pattern 'postgres://*'""",
+  gable contract bulk-update-enforcement-levels ALERT data-asset-id-pattern 'postgres://*'
+  gable contract bulk-update-enforcement-levels BLOCK --dry-run""",
 )
 @click.option(
     "--enforcement-level",
@@ -154,10 +156,18 @@ def _validate_contract_chunk(
     type=str,
     help="""Regex pattern to match data asset IDs. Only the contracts that have associated data assets that match the provided data asset id pattern will be updated.""",
 )
+@click.option(
+    "--dry-run",
+    is_flag=True,
+    help="""Show what would be updated without actually making changes.""",
+)
 @global_options()
 @click.pass_context
 def bulk_update_enforcement_levels(
-    ctx: ClickContext, enforcement_level: str, data_asset_id_pattern: Optional[str]
+    ctx: ClickContext,
+    enforcement_level: str,
+    data_asset_id_pattern: Optional[str],
+    dry_run: bool,
 ):
     """
     Updates the enforcement level of all contracts to the given enforcement level.
@@ -176,24 +186,45 @@ def bulk_update_enforcement_levels(
         if not contract.contractSpec.dataAssetResourceName:
             continue
 
-        darn: str = contract.contractSpec.dataAssetResourceName.__root__
+        darn: str = contract.contractSpec.dataAssetResourceName.root
         if data_asset_id_pattern is None or re.match(data_asset_id_pattern, darn):
             # Only update the enforcement level if the data asset id matches the pattern (or when no pattern was provided)
             contract_input = _create_contract_input(contract, enforcement_level)
-            contract_inputs.append(contract_input)
+            if contract_input is not None:
+                contract_inputs.append(contract_input)
 
-    # Call the postContract endpoint to update the contracts
-    request = PostContractRequest(__root__=contract_inputs)
-    response, _success, _status_code = client.post_contract(request)
-    if isinstance(response, PostContractResponse):
-        logger.info(f"Updated {len(response.contractIds)} contract(s)")
+    if dry_run:
+        logger.info(
+            f"DRY RUN: Would update {len(contract_inputs)} contract(s) to enforcement level {enforcement_level.name}"
+        )
+        for contract_input in contract_inputs:
+            data_asset_name = (
+                contract_input.contractSpec.dataAssetResourceName.root
+                if contract_input.contractSpec.dataAssetResourceName
+                else "No data asset"
+            )
+            logger.info(f"  - Contract {contract_input.id}: {data_asset_name}")
     else:
-        logger.error(f"Failed to update contracts, error: {response}")
+        # Call the postContract endpoint to update the contracts
+        request = PostContractRequest(root=contract_inputs)
+        response, _success, _status_code = client.post_contract(request)
+        if isinstance(response, PostContractResponse):
+            logger.info(f"Updated {len(response.contractIds)} contract(s)")
+        else:
+            logger.error(f"Failed to update contracts, error: {response}")
 
 
 def _create_contract_input(
     contract: ContractOutput, enforcement_level: EnforcementLevel
 ):
+    # Skip contracts that don't have a valid filePath since ContractInput requires it
+    if not contract.filePath:
+        return None
+
+    # Skip contracts with absolute paths since ContractInput.filePath pattern requires relative paths
+    if contract.filePath.startswith("/"):
+        return None
+
     return ContractInput(
         id=contract.id,
         version=contract.version,
@@ -202,7 +233,7 @@ def _create_contract_input(
         gitRepo=contract.gitRepo,
         gitUser=contract.gitUser,
         reviewers=contract.reviewers,
-        filePath=contract.filePath or "",
+        filePath=contract.filePath,
         mergedAt=contract.mergedAt,
         enforcementLevel=enforcement_level,
         contractSpec=contract.contractSpec,
