@@ -12,7 +12,6 @@ from gable.cli.commands.asset_plugins.baseclass import (
     ExtractedAsset,
 )
 from gable.cli.commands.asset_plugins.json_schema import JsonSchemaAssetPlugin
-from gable.cli.commands.asset_plugins.kotlin import KotlinAssetPlugin
 from gable.cli.commands.asset_plugins.mssql import MsSQLAssetPlugin
 from gable.cli.commands.asset_plugins.mysql import MySQLAssetPlugin
 from gable.cli.commands.asset_plugins.postgres import PostgresAssetPlugin
@@ -38,7 +37,6 @@ GENERIC_REGISTER_OPTION_KEYS = set(["dry_run"])
 
 asset_plugins: List[AssetPluginAbstract] = [
     TypescriptAssetPlugin(),
-    KotlinAssetPlugin(),
     ScaPrimePlugin(SourceType.swift),
     ScaPrimePlugin(SourceType.java),
     ScaPrimePlugin(SourceType.kotlin),
@@ -117,12 +115,17 @@ def plugin_register(
 ):
     extracted_assets = asset_plugin.extract_assets(ctx.obj.client, kwargs)
     if not extracted_assets:
-        raise click.ClickException(
-            f"Error registering data assets: No data assets found to register! You can use the --debug or --trace flags for more details."
+        click.echo(
+            click.style(
+                f"Found 0 {asset_plugin.source_type()} data assets, nothing to register.",
+                fg="bright_yellow",
+            )
+        )
+        return
+    else:
+        click.echo(
+            f"Found {len(extracted_assets)} {asset_plugin.source_type()} data asset(s):"
         )
-    click.echo(
-        f"Found {len(extracted_assets)} {asset_plugin.source_type()} data asset(s):"
-    )
     for asset in extracted_assets:
         darn_str = darn_to_string(asset.darn)
         click.echo(f"- {darn_str}")
