@@ -40,7 +40,7 @@ def git_info(path: os.PathLike):
 @click.pass_context
 def env(_ctx: ClickContext):
     """Prints the environment variables used to configure Gable"""
-    env_vars = ["GABLE_API_ENDPOINT", "GABLE_API_KEY"]
+    env_vars = ["GABLE_API_ENDPOINT", "GABLE_API_KEY", "GABLE_API_HEADERS"]
     for env_var in env_vars:
         logger.info(f"  {env_var}={os.environ.get(env_var, '<Not Set>')}")
     logger.info(
