@@ -2,6 +2,7 @@ import json
 import os
 import re
 import subprocess
+import tempfile
 from pathlib import Path
 from typing import Any, List, Optional, Tuple, TypedDict, cast
 
@@ -15,7 +16,6 @@ from gable.cli.helpers.npm import (
     prepare_npm_environment,
     run_sca_pyspark,
     run_sca_python,
-    run_sca_typescript,
 )
 from gable.cli.helpers.repo_interactions import (
     get_git_repo_info,
@@ -34,6 +34,8 @@ from gable.openapi import (
     CheckDataAssetNoContractResponse,
     CheckDataAssetResponse,
     EnforcementLevel,
+    GetConfigRequest,
+    GetConfigResponse,
     SourceType,
     StructuredDataAssetResourceName,
 )
@@ -434,3 +436,48 @@ def recap_type_to_dict(recap_type) -> dict[str, Any]:
         type_dict = recap_type_to_dict_output
     type_dict = alias_dict(type_dict, RECAP_TYPE_REGISTRY)
     return type_dict
+
+
+def merge_rules_file_with_backend_config(
+    rules_file: str | None,
+    client: GableAPIClient,
+    language: SourceType,
+    project_root: str,
+) -> str | None:
+    if rules_file:
+        return rules_file
+
+    git_repo = get_git_repo(project_root)
+    backend_rules_config = client.get_config(
+        GetConfigRequest(
+            config_type="sca_prime",
+            language=language,
+            repo=git_repo,
+            project_root=project_root,
+            # version=TODO
+        )
+    )
+    if backend_rules_config is None:
+        return None
+    backend_rules_config_json = json.dumps(backend_rules_config.config_value)
+    temp_file = tempfile.mktemp()
+    with open(temp_file, "w") as f:
+        f.write(backend_rules_config_json)
+    return temp_file
+
+
+def merge_dataflow_config_file_with_backend_config(
+    dataflow_config_file: str | None,
+    backend_config: GetConfigResponse | None,
+) -> str | None:
+    if dataflow_config_file:
+        return dataflow_config_file
+
+    if backend_config is None:
+        return None
+
+    backend_config_json = json.dumps(backend_config.config_value)
+    temp_file = tempfile.mktemp()
+    with open(temp_file, "w") as f:
+        f.write(backend_config_json)
+    return temp_file
