@@ -236,6 +236,12 @@ def run_sca_typescript(
         result_proc_stdout = result_proc.stdout.read() if result_proc.stdout else ""
         result_proc_stderr = "".join(result_proc_stderr_lines)
         if result_proc.returncode != 0:
+            # Log the error details at ERROR level so they're always visible
+            logger.error(f"Gable SCA failed with exit code {result_proc.returncode}")
+            logger.error(f"Command: {' '.join(cmd)}")
+            logger.error(f"Stderr output: {result_proc_stderr}")
+            if result_proc_stdout:
+                logger.error(f"Stdout output: {result_proc_stdout}")
             raise click.ClickException(f"Error running Gable SCA: {result_proc_stderr}")
         logger.debug(result_proc_stdout)
 
@@ -245,10 +251,10 @@ def run_sca_typescript(
         # The sca CLI prints the results to stdout,and everything else to trace/warn/debug/error
         return result_proc_stdout, {}
     except Exception as e:
-        logger.opt(exception=e).debug("Error running Gable SCA")
-        raise click.ClickException(
-            "Error running Gable SCA, run again with --debug to see more details"
-        )
+        # Log the full exception details at ERROR level so they're always visible
+        logger.error(f"Exception occurred while running Gable SCA: {str(e)}")
+        logger.opt(exception=True).error("Full exception traceback:")
+        raise click.ClickException(f"❌ Error running Gable SCA: {str(e)}")
 
 
 def get_sca_cmd(gable_api_endpoint: Union[str, None], args: list[str]) -> list[str]:
