@@ -18,6 +18,7 @@ from gable.openapi import (
     CrossServiceDataStore,
     CrossServiceEdge,
     ErrorResponse,
+    GetConfigResponse,
     OutputFormat,
     PostScaStartRunRequest,
     S3PresignedUrl,
@@ -37,7 +38,8 @@ def start_sca_run(
     external_component_id: str | None,
     upload_type: Type | None,
     repo_name: str | None,
-) -> Tuple[str, S3PresignedUrl]:
+    external_run_id: str | None = None,
+) -> Tuple[str, S3PresignedUrl | None, GetConfigResponse | None]:
     """Call the SCA start run API to get the S3 presigned URL to upload the SCA results
 
     Args:
@@ -45,7 +47,8 @@ def start_sca_run(
         project_root: The root directory of the project to analyze
 
     Returns:
-        A tuple of (run_id, presigned_url)
+        A tuple of (run_id, presigned_url, config)
+        config will be None if not present in the response
 
     Raises:
         ClickException: If the API call was not successful
@@ -96,6 +99,7 @@ def start_sca_run(
             output_format=output_f,
             include_unchanged_assets=include,
             type=upload_type,
+            run_id=external_run_id,
         )
     )
 
@@ -104,7 +108,7 @@ def start_sca_run(
             f"Error starting static code analysis run: {response.title} - {response.message}"  # type: ignore
         )
 
-    return response.runId, response.s3PresignedUrl  # type: ignore
+    return response.runId, response.s3PresignedUrl, response.config
 
 
 def get_sca_package_info() -> tuple[str, str]:
@@ -205,9 +209,11 @@ def upload_sca_results(
             paths=lineage_data_file.paths,
             external_component_id=lineage_data_file.external_component_id,
             name=lineage_data_file.name,
+            metadata=lineage_data_file.metadata,
         )
     elif isinstance(lineage_data_file, CrossServiceDataStore):
         upload_request = CrossServiceDataStore(
+            run_id=run_id,
             external_component_id=lineage_data_file.external_component_id,
             type=lineage_data_file.type,
             external_table_id=lineage_data_file.external_table_id,
@@ -216,6 +222,7 @@ def upload_sca_results(
         )
     elif isinstance(lineage_data_file, CrossServiceEdge):
         upload_request = CrossServiceEdge(
+            run_id=run_id,
             source_component_id=lineage_data_file.source_component_id,
             destination_component_id=lineage_data_file.destination_component_id,
             external_edge_id=lineage_data_file.external_edge_id,
