@@ -9,6 +9,7 @@ from click_option_group import OptionGroup, optgroup
 from loguru import logger
 
 from gable.cli.client import GableCliClient
+from gable.cli.helpers.exclude_options import resolve_excludes_from_flag_and_rules
 from gable.cli.helpers.logging import configure_debug_logger, configure_trace_logger
 from gable.cli.helpers.multi_option import MultiOption
 from gable.cli.option_defaults import (
@@ -506,6 +507,13 @@ def typescript_project_options(
         )
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
+            exclude = kwargs.get("exclude")
+            rules_file = kwargs.get("rules_file")
+            if exclude and rules_file:
+                kwargs["exclude"] = resolve_excludes_from_flag_and_rules(
+                    exclude,
+                    rules_file,
+                )
             return func(*args, **kwargs)
 
         return wrapper
