@@ -1,6 +1,6 @@
 from typing import Optional
 
-from .openapi import SourceType, StaticAnalysisPathsUploadRequest
+from .openapi import CrossServiceDataStore, SourceType, StaticAnalysisPathsUploadRequest
 
 ALL_SOURCE_TYPES = list(SourceType)
 
@@ -26,3 +26,9 @@ class LineageDataFile(StaticAnalysisPathsUploadRequest):
     run_id: Optional[str] = (
         None  # make optional for upload direct file, we will add this before upload
     )
+
+
+class LineageDataStore(CrossServiceDataStore):
+    run_id: Optional[str] = (
+        None  # make optional for upload direct file, we will add this before upload
+    )
