@@ -20,8 +20,8 @@ from .models import ContractPublishResponse, ExternalContractInput, TrinoDataTyp
 
 
 class GableContract:
-    def __init__(self, api_endpoint, api_key) -> None:
-        self.api_client = GableAPIClient(api_endpoint, api_key)
+    def __init__(self, api_client: GableAPIClient) -> None:
+        self.api_client = api_client
 
     def publish(
         self,
